@@ -673,10 +673,7 @@ class Firebot:
             try:
                 response = requests.post(f"{self.url}api/v1/effects/",
                                         headers={"content-type": "application/json"}, data=json.dumps(data))
-                if response.json() == {"status": "success"}:
-                    break
-                else:
-                    print("Failed")
+                break
             except:
                 attempts += 1
 
@@ -701,6 +698,7 @@ class Firebot:
                 status = json.loads(r.text)
                 if status['status'] == "success":
                     print(f"Successfully executed {name} preset effect")
+                    return
                 else:
                     print(
                         f"Failed to execute {name} preset effect. Check spelling and capitalization")
@@ -895,4 +893,3 @@ class Firebot:
         }
         message = f"Successfully removed {amount} {currency} to all users in {role} role"
         self.sendit(data, message)
-
